**Terminal Velocity is looking for a new maintainer**

I don't use Terminal Velocity anymore and don't have time to work on it.
If you'd like to take it on: fork it, start pushing your changes to your own fork,
get in touch with me and I'll add a link from my copy to your fork and
make you an owner of the Terminal Velocity package on PyPI.

Terminal Velocity
=================


`Terminal Velocity` is a fast note-taking app for the UNIX terminal, that
focuses on letting you create or find a note as quickly and easily as possible,
then uses your ``$EDITOR`` to open and edit the note. It is heavily inspired
by the OS X app `Notational Velocity <http://notational.net/>`_.
For screenshots and features, see the
`Terminal Velocity website <http://seanh.github.com/terminal_velocity>`_.

To install Terminal Velocity, run::

    pip install terminal_velocity

Then to launch it just run::

    terminal_velocity

To use a different notes directory, run::

    terminal_velocity path/to/your/notes/dir

To see all the command-line options, run::

    terminal_velocity -h

To quit the app, press ``ctrl-c`` or ``ctrl-x``.

To upgrade Terminal Velocity to the latest version, run::

    pip install --upgrade terminal_velocity

To uninstall it, run::

    pip uninstall terminal_velocity

To make a bug report or feature request, use `GitHub Issues <https://github.com/seanh/terminal_velocity/issues>`_.

To contribute documentation, use `the wiki <https://github.com/seanh/terminal_velocity/wiki>`_.

To contribute code to Terminal Velocity, see
`CONTRIBUTING <https://github.com/seanh/terminal_velocity/blob/master/CONTRIBUTING.md#contributing-to-terminal-velocity>`_.

